Type: Package
Package: ceRNAnetsim
Title: Regulation Simulator of Interaction between miRNA and Competing
        RNAs (ceRNA)
Version: 1.23.0
Authors@R: 
    c(person(given = "Selcen",
             family = "Ari Yuka",
             role = c("aut", "cre"),
             email = "selcenarii@gmail.com",
             comment = c(ORCID = "0000-0002-0028-2453")),
      person(given = "Alper",
             family = "Yilmaz",
             role = "aut",
             email = "alperyilmaz@gmail.com",
             comment = c(ORCID = "0000-0002-8827-4887")))
Description: This package simulates regulations of ceRNA
    (Competing Endogenous) expression levels after a expression level
    change in one or more miRNA/mRNAs. The methodolgy adopted by the
    package has potential to incorparate any ceRNA (circRNA, lincRNA,
    etc.) into miRNA:target interaction network.  The package basically
    distributes miRNA expression over available ceRNAs where each ceRNA
    attracks miRNAs proportional to its amount. But, the package can
    utilize multiple parameters that modify miRNA effect on its target
    (seed type, binding energy, binding location, etc.).  The functions
    handle the given dataset as graph object and the processes progress
    via edge and node variables.
License: GPL (>= 3.0)
URL: https://github.com/selcenari/ceRNAnetsim
BugReports: https://github.com/selcenari/ceRNAnetsim/issues
Depends: R (>= 4.0.0), dplyr, tidygraph
Imports: furrr, rlang, tibble, ggplot2, ggraph, igraph, purrr, tidyr,
        future, stats
Suggests: knitr, png, rmarkdown, testthat, covr
VignetteBuilder: knitr
biocViews: NetworkInference, SystemsBiology, Network, GraphAndNetwork,
        Transcriptomics
Encoding: UTF-8
LazyData: false
RoxygenNote: 7.1.2
git_url: https://git.bioconductor.org/packages/ceRNAnetsim
git_branch: devel
git_last_commit: 4b53125
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
NeedsCompilation: no
Packaged: 2025-10-30 20:32:34 UTC; biocbuild
Author: Selcen Ari Yuka [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0028-2453>),
  Alper Yilmaz [aut] (ORCID: <https://orcid.org/0000-0002-8827-4887>)
Maintainer: Selcen Ari Yuka <selcenarii@gmail.com>
