utils::globalVariables(c("name", "count_current", "initial_count", ".",
                         "from", "comp_count_list", "dif", "non_zero",
                         "effect", "iter", "nodes", "eff_count",
                         "effect_current", "comp_count_current",
                         "mirna_count_current", "Competing_name",
                         "comp_count_pre", "miRNA_name", "dummy",
                         "competing", "miRNA", "nodes", "to",
                         "afff_factor", "mirna_count_per_dep",
                         "degg_factor", "mirna_count_per_comp",
                         "effect_list", "mirna_count_list",
                         "count_pre", "type", "node_id",
                         "changes_variable", "x", "y",
                         "mirna_count_pre", "effect_pre", "len",
                         "change", "node", "top_nodes", "initial_exp", "final_exp"))
