% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/update_nodes.R
\name{prepare_rhs_once}
\alias{prepare_rhs_once}
\title{Carries the variables from edge to node.}
\usage{
prepare_rhs_once(input_graph)
}
\arguments{
\item{input_graph}{Processed graph object in previous step.}
}
\value{
tibble object
}
\description{
Carries the variables from edge to node.
}
\details{
The function is a helper function for
processing of graph object with update_nodes function.
}
\keyword{internal}
